Documentation
¶
Overview ¶
internal/admin/handler.go
internal/admin/schema.go
Index ¶
Constants ¶
const SchemaVersion = "1"
SchemaVersion is bumped only on breaking changes to admin/JSON responses.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Core ¶
type Core interface {
Secret() string
Revoke(id string) error
List() ListResponse
Status() StatusResponse
Stop()
}
Core is the subset of the daemon that the admin handler needs.
type ListResponse ¶
type ListResponse struct {
SchemaVersion string `json:"schema_version"`
}
type OKResponse ¶
type SharePayload ¶
type SharePayload struct {
}
type ShareRequest ¶
type ShareRequest struct {
}
Click to show internal directories.
Click to hide internal directories.